Class: Aws::NetworkFlowMonitor::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::NetworkFlowMonitor::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-networkflowmonitor/client.rb
Overview
An API client for NetworkFlowMonitor. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::NetworkFlowMonitor::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_monitor(params = {}) ⇒ Types::CreateMonitorOutput
Create a monitor for specific network flows between local and remote resources, so that you can monitor network performance for one or several of your workloads.
-
#create_scope(params = {}) ⇒ Types::CreateScopeOutput
In Network Flow Monitor, you specify a scope for the service to generate metrics for.
-
#delete_monitor(params = {}) ⇒ Struct
Deletes a monitor in Network Flow Monitor.
-
#delete_scope(params = {}) ⇒ Struct
Deletes a scope that has been defined.
-
#get_monitor(params = {}) ⇒ Types::GetMonitorOutput
Gets information about a monitor in Network Flow Monitor based on a monitor name.
-
#get_query_results_monitor_top_contributors(params = {}) ⇒ Types::GetQueryResultsMonitorTopContributorsOutput
Return the data for a query with the Network Flow Monitor query interface.
-
#get_query_results_workload_insights_top_contributors(params = {}) ⇒ Types::GetQueryResultsWorkloadInsightsTopContributorsOutput
Return the data for a query with the Network Flow Monitor query interface.
-
#get_query_results_workload_insights_top_contributors_data(params = {}) ⇒ Types::GetQueryResultsWorkloadInsightsTopContributorsDataOutput
Return the data for a query with the Network Flow Monitor query interface.
-
#get_query_status_monitor_top_contributors(params = {}) ⇒ Types::GetQueryStatusMonitorTopContributorsOutput
Returns the current status of a query for the Network Flow Monitor query interface, for a specified query ID and monitor.
-
#get_query_status_workload_insights_top_contributors(params = {}) ⇒ Types::GetQueryStatusWorkloadInsightsTopContributorsOutput
Return the data for a query with the Network Flow Monitor query interface.
-
#get_query_status_workload_insights_top_contributors_data(params = {}) ⇒ Types::GetQueryStatusWorkloadInsightsTopContributorsDataOutput
Returns the current status of a query for the Network Flow Monitor query interface, for a specified query ID and monitor.
-
#get_scope(params = {}) ⇒ Types::GetScopeOutput
Gets information about a scope, including the name, status, tags, and target details.
-
#list_monitors(params = {}) ⇒ Types::ListMonitorsOutput
List all monitors in an account.
-
#list_scopes(params = {}) ⇒ Types::ListScopesOutput
List all the scopes for an account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns all the tags for a resource.
-
#start_query_monitor_top_contributors(params = {}) ⇒ Types::StartQueryMonitorTopContributorsOutput
Create a query that you can use with the Network Flow Monitor query interface to return the top contributors for a monitor.
-
#start_query_workload_insights_top_contributors(params = {}) ⇒ Types::StartQueryWorkloadInsightsTopContributorsOutput
Create a query with the Network Flow Monitor query interface that you can run to return workload insights top contributors.
-
#start_query_workload_insights_top_contributors_data(params = {}) ⇒ Types::StartQueryWorkloadInsightsTopContributorsDataOutput
Create a query with the Network Flow Monitor query interface that you can run to return data for workload insights top contributors.
-
#stop_query_monitor_top_contributors(params = {}) ⇒ Struct
Stop a top contributors query for a monitor.
-
#stop_query_workload_insights_top_contributors(params = {}) ⇒ Struct
Stop a top contributors query for workload insights.
-
#stop_query_workload_insights_top_contributors_data(params = {}) ⇒ Struct
Stop a top contributors data query for workload insights.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
-
#update_monitor(params = {}) ⇒ Types::UpdateMonitorOutput
Update a monitor to add or remove local or remote resources.
-
#update_scope(params = {}) ⇒ Types::UpdateScopeOutput
Update a scope to add or remove resources that you want to be available for Network Flow Monitor to generate metrics for, when you have active agents on those resources sending metrics reports to the Network Flow Monitor backend.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1972 1973 1974 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1972 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1975 1976 1977 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1975 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1945 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::NetworkFlowMonitor') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-networkflowmonitor' context[:gem_version] = '1.26.0' Seahorse::Client::Request.new(handlers, context) end |
#create_monitor(params = {}) ⇒ Types::CreateMonitorOutput
Create a monitor for specific network flows between local and remote resources, so that you can monitor network performance for one or several of your workloads. For each monitor, Network Flow Monitor publishes detailed end-to-end performance metrics and a network health indicator (NHI) that informs you whether there were Amazon Web Services network issues for one or more of the network flows tracked by a monitor, during a time period that you choose.
589 590 591 592 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 589 def create_monitor(params = {}, = {}) req = build_request(:create_monitor, params) req.send_request() end |
#create_scope(params = {}) ⇒ Types::CreateScopeOutput
In Network Flow Monitor, you specify a scope for the service to generate metrics for. By using the scope, Network Flow Monitor can generate a topology of all the resources to measure performance metrics for. When you create a scope, you enable permissions for Network Flow Monitor.
A scope is a Region-account pair or multiple Region-account pairs. Network Flow Monitor uses your scope to determine all the resources (the topology) where Network Flow Monitor will gather network flow performance metrics for you. To provide performance metrics, Network Flow Monitor uses the data that is sent by the Network Flow Monitor agents you install on the resources.
To define the Region-account pairs for your scope, the Network Flow Monitor API uses the following constucts, which allow for future flexibility in defining scopes:
-
Targets, which are arrays of targetResources.
-
*Target resources*, which are Region-targetIdentifier pairs.
-
*Target identifiers*, made up of a targetID (currently always an account ID) and a targetType (currently always an account).
673 674 675 676 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 673 def create_scope(params = {}, = {}) req = build_request(:create_scope, params) req.send_request() end |
#delete_monitor(params = {}) ⇒ Struct
Deletes a monitor in Network Flow Monitor.
695 696 697 698 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 695 def delete_monitor(params = {}, = {}) req = build_request(:delete_monitor, params) req.send_request() end |
#delete_scope(params = {}) ⇒ Struct
Deletes a scope that has been defined.
719 720 721 722 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 719 def delete_scope(params = {}, = {}) req = build_request(:delete_scope, params) req.send_request() end |
#get_monitor(params = {}) ⇒ Types::GetMonitorOutput
Gets information about a monitor in Network Flow Monitor based on a monitor name. The information returned includes the Amazon Resource Name (ARN), create time, modified time, resources included in the monitor, and status information.
769 770 771 772 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 769 def get_monitor(params = {}, = {}) req = build_request(:get_monitor, params) req.send_request() end |
#get_query_results_monitor_top_contributors(params = {}) ⇒ Types::GetQueryResultsMonitorTopContributorsOutput
Return the data for a query with the Network Flow Monitor query interface. You specify the query that you want to return results for by providing a query ID and a monitor name. This query returns the top contributors for a specific monitor.
Create a query ID for this call by calling the corresponding API call to start the query, ‘StartQueryMonitorTopContributors`. Use the scope ID that was returned for your account by `CreateScope`.
Top contributors in Network Flow Monitor are network flows with the highest values for a specific metric type. Top contributors can be across all workload insights, for a given scope, or for a specific monitor. Use the applicable call for the top contributors that you want to be returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
865 866 867 868 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 865 def get_query_results_monitor_top_contributors(params = {}, = {}) req = build_request(:get_query_results_monitor_top_contributors, params) req.send_request() end |
#get_query_results_workload_insights_top_contributors(params = {}) ⇒ Types::GetQueryResultsWorkloadInsightsTopContributorsOutput
Return the data for a query with the Network Flow Monitor query interface. You specify the query that you want to return results for by providing a query ID and a monitor name.
This query returns the top contributors for a scope for workload insights. Workload insights provide a high level view of network flow performance data collected by agents. To return the data for the top contributors, see ‘GetQueryResultsWorkloadInsightsTopContributorsData`.
Create a query ID for this call by calling the corresponding API call to start the query, ‘StartQueryWorkloadInsightsTopContributors`. Use the scope ID that was returned for your account by `CreateScope`.
Top contributors in Network Flow Monitor are network flows with the highest values for a specific metric type. Top contributors can be across all workload insights, for a given scope, or for a specific monitor. Use the applicable call for the top contributors that you want to be returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
941 942 943 944 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 941 def get_query_results_workload_insights_top_contributors(params = {}, = {}) req = build_request(:get_query_results_workload_insights_top_contributors, params) req.send_request() end |
#get_query_results_workload_insights_top_contributors_data(params = {}) ⇒ Types::GetQueryResultsWorkloadInsightsTopContributorsDataOutput
Return the data for a query with the Network Flow Monitor query interface. Specify the query that you want to return results for by providing a query ID and a scope ID.
This query returns the data for top contributors for workload insights for a specific scope. Workload insights provide a high level view of network flow performance data collected by agents for a scope. To return just the top contributors, see ‘GetQueryResultsWorkloadInsightsTopContributors`.
Create a query ID for this call by calling the corresponding API call to start the query, ‘StartQueryWorkloadInsightsTopContributorsData`. Use the scope ID that was returned for your account by `CreateScope`.
Top contributors in Network Flow Monitor are network flows with the highest values for a specific metric type. Top contributors can be across all workload insights, for a given scope, or for a specific monitor. Use the applicable call for the top contributors that you want to be returned.
The top contributor network flows overall are for a specific metric type, for example, the number of retransmissions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1018 1019 1020 1021 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1018 def get_query_results_workload_insights_top_contributors_data(params = {}, = {}) req = build_request(:get_query_results_workload_insights_top_contributors_data, params) req.send_request() end |
#get_query_status_monitor_top_contributors(params = {}) ⇒ Types::GetQueryStatusMonitorTopContributorsOutput
Returns the current status of a query for the Network Flow Monitor query interface, for a specified query ID and monitor. This call returns the query status for the top contributors for a monitor.
When you create a query, use this call to check the status of the query to make sure that it has has ‘SUCCEEDED` before you review the results. Use the same query ID that you used for the corresponding API call to start (create) the query, `StartQueryMonitorTopContributors`.
When you run a query, use this call to check the status of the query to make sure that the query has ‘SUCCEEDED` before you review the results.
1063 1064 1065 1066 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1063 def get_query_status_monitor_top_contributors(params = {}, = {}) req = build_request(:get_query_status_monitor_top_contributors, params) req.send_request() end |
#get_query_status_workload_insights_top_contributors(params = {}) ⇒ Types::GetQueryStatusWorkloadInsightsTopContributorsOutput
Return the data for a query with the Network Flow Monitor query interface. Specify the query that you want to return results for by providing a query ID and a monitor name. This query returns the top contributors for workload insights.
When you start a query, use this call to check the status of the query to make sure that it has has ‘SUCCEEDED` before you review the results. Use the same query ID that you used for the corresponding API call to start the query, `StartQueryWorkloadInsightsTopContributors`.
Top contributors in Network Flow Monitor are network flows with the highest values for a specific metric type. Top contributors can be across all workload insights, for a given scope, or for a specific monitor. Use the applicable call for the top contributors that you want to be returned.
1113 1114 1115 1116 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1113 def get_query_status_workload_insights_top_contributors(params = {}, = {}) req = build_request(:get_query_status_workload_insights_top_contributors, params) req.send_request() end |
#get_query_status_workload_insights_top_contributors_data(params = {}) ⇒ Types::GetQueryStatusWorkloadInsightsTopContributorsDataOutput
Returns the current status of a query for the Network Flow Monitor query interface, for a specified query ID and monitor. This call returns the query status for the top contributors data for workload insights.
When you start a query, use this call to check the status of the query to make sure that it has has ‘SUCCEEDED` before you review the results. Use the same query ID that you used for the corresponding API call to start the query, `StartQueryWorkloadInsightsTopContributorsData`.
Top contributors in Network Flow Monitor are network flows with the highest values for a specific metric type. Top contributors can be across all workload insights, for a given scope, or for a specific monitor. Use the applicable call for the top contributors that you want to be returned.
The top contributor network flows overall are for a specific metric type, for example, the number of retransmissions.
1168 1169 1170 1171 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1168 def get_query_status_workload_insights_top_contributors_data(params = {}, = {}) req = build_request(:get_query_status_workload_insights_top_contributors_data, params) req.send_request() end |
#get_scope(params = {}) ⇒ Types::GetScopeOutput
Gets information about a scope, including the name, status, tags, and target details. The scope in Network Flow Monitor is an account.
1212 1213 1214 1215 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1212 def get_scope(params = {}, = {}) req = build_request(:get_scope, params) req.send_request() end |
#list_monitors(params = {}) ⇒ Types::ListMonitorsOutput
List all monitors in an account. Optionally, you can list only monitors that have a specific status, by using the ‘STATUS` parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1267 1268 1269 1270 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1267 def list_monitors(params = {}, = {}) req = build_request(:list_monitors, params) req.send_request() end |
#list_scopes(params = {}) ⇒ Types::ListScopesOutput
List all the scopes for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1307 1308 1309 1310 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1307 def list_scopes(params = {}, = {}) req = build_request(:list_scopes, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns all the tags for a resource.
1336 1337 1338 1339 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1336 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_query_monitor_top_contributors(params = {}) ⇒ Types::StartQueryMonitorTopContributorsOutput
Create a query that you can use with the Network Flow Monitor query interface to return the top contributors for a monitor. Specify the monitor that you want to create the query for.
The call returns a query ID that you can use with [ GetQueryResultsMonitorTopContributors] to run the query and return the top contributors for a specific monitor.
Top contributors in Network Flow Monitor are network flows with the highest values for a specific metric type. Top contributors can be across all workload insights, for a given scope, or for a specific monitor. Use the applicable APIs for the top contributors that you want to be returned.
1425 1426 1427 1428 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1425 def start_query_monitor_top_contributors(params = {}, = {}) req = build_request(:start_query_monitor_top_contributors, params) req.send_request() end |
#start_query_workload_insights_top_contributors(params = {}) ⇒ Types::StartQueryWorkloadInsightsTopContributorsOutput
Create a query with the Network Flow Monitor query interface that you can run to return workload insights top contributors. Specify the scope that you want to create a query for.
The call returns a query ID that you can use with [ GetQueryResultsWorkloadInsightsTopContributors] to run the query and return the top contributors for the workload insights for a scope.
Top contributors in Network Flow Monitor are network flows with the highest values for a specific metric type. Top contributors can be across all workload insights, for a given scope, or for a specific monitor. Use the applicable APIs for the top contributors that you want to be returned.
1514 1515 1516 1517 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1514 def start_query_workload_insights_top_contributors(params = {}, = {}) req = build_request(:start_query_workload_insights_top_contributors, params) req.send_request() end |
#start_query_workload_insights_top_contributors_data(params = {}) ⇒ Types::StartQueryWorkloadInsightsTopContributorsDataOutput
Create a query with the Network Flow Monitor query interface that you can run to return data for workload insights top contributors. Specify the scope that you want to create a query for.
The call returns a query ID that you can use with [ GetQueryResultsWorkloadInsightsTopContributorsData] to run the query and return the data for the top contributors for the workload insights for a scope.
Top contributors in Network Flow Monitor are network flows with the highest values for a specific metric type. Top contributors can be across all workload insights, for a given scope, or for a specific monitor. Use the applicable call for the top contributors that you want to be returned.
1599 1600 1601 1602 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1599 def start_query_workload_insights_top_contributors_data(params = {}, = {}) req = build_request(:start_query_workload_insights_top_contributors_data, params) req.send_request() end |
#stop_query_monitor_top_contributors(params = {}) ⇒ Struct
Stop a top contributors query for a monitor. Specify the query that you want to stop by providing a query ID and a monitor name.
Top contributors in Network Flow Monitor are network flows with the highest values for a specific metric type. Top contributors can be across all workload insights, for a given scope, or for a specific monitor. Use the applicable call for the top contributors that you want to be returned.
1634 1635 1636 1637 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1634 def stop_query_monitor_top_contributors(params = {}, = {}) req = build_request(:stop_query_monitor_top_contributors, params) req.send_request() end |
#stop_query_workload_insights_top_contributors(params = {}) ⇒ Struct
Stop a top contributors query for workload insights. Specify the query that you want to stop by providing a query ID and a scope ID.
Top contributors in Network Flow Monitor are network flows with the highest values for a specific metric type. Top contributors can be across all workload insights, for a given scope, or for a specific monitor. Use the applicable call for the top contributors that you want to be returned.
1671 1672 1673 1674 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1671 def stop_query_workload_insights_top_contributors(params = {}, = {}) req = build_request(:stop_query_workload_insights_top_contributors, params) req.send_request() end |
#stop_query_workload_insights_top_contributors_data(params = {}) ⇒ Struct
Stop a top contributors data query for workload insights. Specify the query that you want to stop by providing a query ID and a scope ID.
Top contributors in Network Flow Monitor are network flows with the highest values for a specific metric type. Top contributors can be across all workload insights, for a given scope, or for a specific monitor. Use the applicable call for the top contributors that you want to be returned.
1708 1709 1710 1711 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1708 def stop_query_workload_insights_top_contributors_data(params = {}, = {}) req = build_request(:stop_query_workload_insights_top_contributors_data, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
1736 1737 1738 1739 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1736 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
1762 1763 1764 1765 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1762 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_monitor(params = {}) ⇒ Types::UpdateMonitorOutput
Update a monitor to add or remove local or remote resources.
1868 1869 1870 1871 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1868 def update_monitor(params = {}, = {}) req = build_request(:update_monitor, params) req.send_request() end |
#update_scope(params = {}) ⇒ Types::UpdateScopeOutput
Update a scope to add or remove resources that you want to be available for Network Flow Monitor to generate metrics for, when you have active agents on those resources sending metrics reports to the Network Flow Monitor backend.
1936 1937 1938 1939 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1936 def update_scope(params = {}, = {}) req = build_request(:update_scope, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1965 1966 1967 |
# File 'lib/aws-sdk-networkflowmonitor/client.rb', line 1965 def waiter_names [] end |