Class: Aws::NetworkFlowMonitor::Types::GetMonitorOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkflowmonitor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time when the monitor was created.

Returns:

  • (Time)


331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331

class GetMonitorOutput < Struct.new(
  :monitor_arn,
  :monitor_name,
  :monitor_status,
  :local_resources,
  :remote_resources,
  :created_at,
  :modified_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#local_resourcesArray<Types::MonitorLocalResource>

The local resources to monitor. A local resource in a workload is the location of the hosts where the Network Flow Monitor agent is installed.

Returns:



331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331

class GetMonitorOutput < Struct.new(
  :monitor_arn,
  :monitor_name,
  :monitor_status,
  :local_resources,
  :remote_resources,
  :created_at,
  :modified_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime

The date and time when the monitor was last modified.

Returns:

  • (Time)


331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331

class GetMonitorOutput < Struct.new(
  :monitor_arn,
  :monitor_name,
  :monitor_status,
  :local_resources,
  :remote_resources,
  :created_at,
  :modified_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#monitor_arnString

The Amazon Resource Name (ARN) of the monitor.

Returns:

  • (String)


331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331

class GetMonitorOutput < Struct.new(
  :monitor_arn,
  :monitor_name,
  :monitor_status,
  :local_resources,
  :remote_resources,
  :created_at,
  :modified_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#monitor_nameString

The name of the monitor.

Returns:

  • (String)


331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331

class GetMonitorOutput < Struct.new(
  :monitor_arn,
  :monitor_name,
  :monitor_status,
  :local_resources,
  :remote_resources,
  :created_at,
  :modified_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#monitor_statusString

The status of a monitor. The status can be one of the following

  • PENDING: The monitor is in the process of being created.

  • ACTIVE: The monitor is active.

  • INACTIVE: The monitor is inactive.

  • ERROR: Monitor creation failed due to an error.

  • DELETING: The monitor is in the process of being deleted.

Returns:

  • (String)


331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331

class GetMonitorOutput < Struct.new(
  :monitor_arn,
  :monitor_name,
  :monitor_status,
  :local_resources,
  :remote_resources,
  :created_at,
  :modified_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#remote_resourcesArray<Types::MonitorRemoteResource>

The remote resources to monitor. A remote resource is the other endpoint specified for the network flow of a workload, with a local resource. For example, Amazon Dynamo DB can be a remote resource.

Returns:



331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331

class GetMonitorOutput < Struct.new(
  :monitor_arn,
  :monitor_name,
  :monitor_status,
  :local_resources,
  :remote_resources,
  :created_at,
  :modified_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags for a monitor.

Returns:

  • (Hash<String,String>)


331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331

class GetMonitorOutput < Struct.new(
  :monitor_arn,
  :monitor_name,
  :monitor_status,
  :local_resources,
  :remote_resources,
  :created_at,
  :modified_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end