Class: Aws::NetworkFlowMonitor::Types::GetQueryStatusWorkloadInsightsTopContributorsDataOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFlowMonitor::Types::GetQueryStatusWorkloadInsightsTopContributorsDataOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkflowmonitor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The status of a query for top contributors data.
Instance Attribute Details
#status ⇒ String
The status of a query for top contributors data.
-
QUEUED: The query is scheduled to run. -
RUNNING: The query is in progress but not complete. -
SUCCEEDED: The query completed sucessfully. -
FAILED: The query failed due to an error. -
CANCELED: The query was canceled.
587 588 589 590 591 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 587 class GetQueryStatusWorkloadInsightsTopContributorsDataOutput < Struct.new( :status) SENSITIVE = [] include Aws::Structure end |