Class: Aws::NetworkFlowMonitor::Types::GetQueryStatusWorkloadInsightsTopContributorsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkflowmonitor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#query_idString

The identifier for the query. A query ID is an internally-generated identifier for a specific query returned from an API call to start a query.

Returns:

  • (String)


608
609
610
611
612
613
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 608

class GetQueryStatusWorkloadInsightsTopContributorsInput < Struct.new(
  :scope_id,
  :query_id)
  SENSITIVE = []
  include Aws::Structure
end

#scope_idString

The identifier for the scope that includes the resources you want to get data results for. A scope ID is an internally-generated identifier that includes all the resources for a specific root account.

Returns:

  • (String)


608
609
610
611
612
613
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 608

class GetQueryStatusWorkloadInsightsTopContributorsInput < Struct.new(
  :scope_id,
  :query_id)
  SENSITIVE = []
  include Aws::Structure
end