Class: Aws::NetworkFlowMonitor::Types::ListScopesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFlowMonitor::Types::ListScopesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkflowmonitor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The number of query results that you want to return with this call.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#max_results ⇒ Integer
The number of query results that you want to return with this call.
812 813 814 815 816 817 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 812 class ListScopesInput < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. You receive this token from a previous call.
812 813 814 815 816 817 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 812 class ListScopesInput < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |