Class: Aws::NetworkFlowMonitor::Types::MonitorLocalResource
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFlowMonitor::Types::MonitorLocalResource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkflowmonitor/types.rb
Overview
A local resource is the host where the agent is installed. Local resources can be a a subnet, a VPC, an Availability Zone, an EKS cluster or an Amazon Web Services Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
The identifier of the local resource.
-
#type ⇒ String
The type of the local resource.
Instance Attribute Details
#identifier ⇒ String
The identifier of the local resource. The values you can specify are the following:
-
For a VPC, subnet or EKS cluster, this identifier is the VPC Amazon Resource Name (ARN), subnet ARN or cluster ARN.
-
For an Availability Zone, this identifier is the AZ name, for example, us-west-2b.
-
For a Region, this identifier is the Region name, for example, us-west-2.
887 888 889 890 891 892 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 887 class MonitorLocalResource < Struct.new( :type, :identifier) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the local resource. Valid values are AWS::EC2::VPC AWS::AvailabilityZone, AWS::EC2::Subnet, AWS::EKS::Cluster, or AWS::Region.
887 888 889 890 891 892 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 887 class MonitorLocalResource < Struct.new( :type, :identifier) SENSITIVE = [] include Aws::Structure end |