Class: Aws::NetworkFlowMonitor::Types::StartQueryMonitorTopContributorsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkflowmonitor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_categoryString

The category that you want to query top contributors for, for a specific monitor. Destination categories can be one of the following:

  • INTRA_AZ: Top contributor network flows within a single Availability Zone

  • INTER_AZ: Top contributor network flows between Availability Zones

  • INTER_REGION: Top contributor network flows between Regions (to the edge of another Region)

  • INTER_VPC: Top contributor network flows between VPCs

  • AMAZON_S3: Top contributor network flows to or from Amazon S3

  • AMAZON_DYNAMODB: Top contributor network flows to or from Amazon Dynamo DB

  • UNCLASSIFIED: Top contributor network flows that do not have a bucket classification

Returns:

  • (String)


1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1255

class StartQueryMonitorTopContributorsInput < Struct.new(
  :monitor_name,
  :start_time,
  :end_time,
  :metric_name,
  :destination_category,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The timestamp that is the date and time end of the period that you want to retrieve results for with your query.

Returns:

  • (Time)


1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1255

class StartQueryMonitorTopContributorsInput < Struct.new(
  :monitor_name,
  :start_time,
  :end_time,
  :metric_name,
  :destination_category,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

The maximum number of top contributors to return.

Returns:

  • (Integer)


1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1255

class StartQueryMonitorTopContributorsInput < Struct.new(
  :monitor_name,
  :start_time,
  :end_time,
  :metric_name,
  :destination_category,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

The metric that you want to query top contributors for. That is, you can specify a metric with this call and return the top contributor network flows, for that type of metric, for a monitor and (optionally) within a specific category, such as network flows between Availability Zones.

Returns:

  • (String)


1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1255

class StartQueryMonitorTopContributorsInput < Struct.new(
  :monitor_name,
  :start_time,
  :end_time,
  :metric_name,
  :destination_category,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#monitor_nameString

The name of the monitor.

Returns:

  • (String)


1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1255

class StartQueryMonitorTopContributorsInput < Struct.new(
  :monitor_name,
  :start_time,
  :end_time,
  :metric_name,
  :destination_category,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The timestamp that is the date and time that is the beginning of the period that you want to retrieve results for with your query.

Returns:

  • (Time)


1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1255

class StartQueryMonitorTopContributorsInput < Struct.new(
  :monitor_name,
  :start_time,
  :end_time,
  :metric_name,
  :destination_category,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end