Class: Aws::NetworkFlowMonitor::Types::TargetIdentifier

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkflowmonitor/types.rb

Overview

A target identifier is a pair of identifying information for a scope that is included in a target. A target identifier is made up of a target ID and a target type. Currently the target ID is always an account ID and the target type is always ACCOUNT.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#target_idTypes::TargetId

The identifier for a target, which is currently always an account ID .

Returns:



1567
1568
1569
1570
1571
1572
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1567

class TargetIdentifier < Struct.new(
  :target_id,
  :target_type)
  SENSITIVE = []
  include Aws::Structure
end

#target_typeString

The type of a target. A target type is currently always ACCOUNT.

Returns:

  • (String)


1567
1568
1569
1570
1571
1572
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1567

class TargetIdentifier < Struct.new(
  :target_id,
  :target_type)
  SENSITIVE = []
  include Aws::Structure
end