Class: Aws::NetworkFlowMonitor::Types::UpdateMonitorInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkflowmonitor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive string of up to 64 ASCII characters that you specify to make an idempotent API request. Don’t reuse the same client token for other API requests.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1707

class UpdateMonitorInput < Struct.new(
  :monitor_name,
  :local_resources_to_add,
  :local_resources_to_remove,
  :remote_resources_to_add,
  :remote_resources_to_remove,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#local_resources_to_addArray<Types::MonitorLocalResource>

Additional local resources to specify network flows for a monitor, as an array of resources with identifiers and types. A local resource in a workload is the location of hosts where the Network Flow Monitor agent is installed.

Returns:



1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1707

class UpdateMonitorInput < Struct.new(
  :monitor_name,
  :local_resources_to_add,
  :local_resources_to_remove,
  :remote_resources_to_add,
  :remote_resources_to_remove,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#local_resources_to_removeArray<Types::MonitorLocalResource>

The local resources to remove, as an array of resources with identifiers and types.

Returns:



1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1707

class UpdateMonitorInput < Struct.new(
  :monitor_name,
  :local_resources_to_add,
  :local_resources_to_remove,
  :remote_resources_to_add,
  :remote_resources_to_remove,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#monitor_nameString

The name of the monitor.

Returns:

  • (String)


1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1707

class UpdateMonitorInput < Struct.new(
  :monitor_name,
  :local_resources_to_add,
  :local_resources_to_remove,
  :remote_resources_to_add,
  :remote_resources_to_remove,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#remote_resources_to_addArray<Types::MonitorRemoteResource>

The remote resources to add, as an array of resources with identifiers and types.

A remote resource is the other endpoint in the flow of a workload, with a local resource. For example, Amazon Dynamo DB can be a remote resource.

Returns:



1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1707

class UpdateMonitorInput < Struct.new(
  :monitor_name,
  :local_resources_to_add,
  :local_resources_to_remove,
  :remote_resources_to_add,
  :remote_resources_to_remove,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#remote_resources_to_removeArray<Types::MonitorRemoteResource>

The remote resources to remove, as an array of resources with identifiers and types.

A remote resource is the other endpoint specified for the network flow of a workload, with a local resource. For example, Amazon Dynamo DB can be a remote resource.

Returns:



1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1707

class UpdateMonitorInput < Struct.new(
  :monitor_name,
  :local_resources_to_add,
  :local_resources_to_remove,
  :remote_resources_to_add,
  :remote_resources_to_remove,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end