Class: Aws::NetworkFlowMonitor::Types::CreateScopeOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFlowMonitor::Types::CreateScopeOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkflowmonitor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#scope_arn ⇒ String
The Amazon Resource Name (ARN) of the scope.
-
#scope_id ⇒ String
The identifier for the scope that includes the resources you want to get metrics for.
-
#status ⇒ String
The status for a scope.
-
#tags ⇒ Hash<String,String>
The tags for a scope.
Instance Attribute Details
#scope_arn ⇒ String
The Amazon Resource Name (ARN) of the scope.
227 228 229 230 231 232 233 234 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 227 class CreateScopeOutput < Struct.new( :scope_id, :status, :scope_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#scope_id ⇒ String
The identifier for the scope that includes the resources you want to get metrics for. A scope ID is an internally-generated identifier that includes all the resources for a specific root account.
227 228 229 230 231 232 233 234 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 227 class CreateScopeOutput < Struct.new( :scope_id, :status, :scope_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status for a scope. The status can be one of the following: SUCCEEDED, IN_PROGRESS, FAILED, DEACTIVATING, or DEACTIVATED.
A status of DEACTIVATING means that you’ve requested a scope to be deactivated and Network Flow Monitor is in the process of deactivating the scope. A status of DEACTIVATED means that the deactivating process is complete.
227 228 229 230 231 232 233 234 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 227 class CreateScopeOutput < Struct.new( :scope_id, :status, :scope_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags for a scope.
227 228 229 230 231 232 233 234 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 227 class CreateScopeOutput < Struct.new( :scope_id, :status, :scope_arn, :tags) SENSITIVE = [] include Aws::Structure end |