Class: Aws::NetworkFlowMonitor::Types::GetMonitorOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFlowMonitor::Types::GetMonitorOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkflowmonitor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time when the monitor was created.
-
#local_resources ⇒ Array<Types::MonitorLocalResource>
The local resources to monitor.
-
#modified_at ⇒ Time
The date and time when the monitor was last modified.
-
#monitor_arn ⇒ String
The Amazon Resource Name (ARN) of the monitor.
-
#monitor_name ⇒ String
The name of the monitor.
-
#monitor_status ⇒ String
The status of a monitor.
-
#remote_resources ⇒ Array<Types::MonitorRemoteResource>
The remote resources to monitor.
-
#tags ⇒ Hash<String,String>
The tags for a monitor.
Instance Attribute Details
#created_at ⇒ Time
The date and time when the monitor was created.
331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331 class GetMonitorOutput < Struct.new( :monitor_arn, :monitor_name, :monitor_status, :local_resources, :remote_resources, :created_at, :modified_at, :tags) SENSITIVE = [] include Aws::Structure end |
#local_resources ⇒ Array<Types::MonitorLocalResource>
The local resources to monitor. A local resource in a workload is the location of the hosts where the Network Flow Monitor agent is installed.
331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331 class GetMonitorOutput < Struct.new( :monitor_arn, :monitor_name, :monitor_status, :local_resources, :remote_resources, :created_at, :modified_at, :tags) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time when the monitor was last modified.
331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331 class GetMonitorOutput < Struct.new( :monitor_arn, :monitor_name, :monitor_status, :local_resources, :remote_resources, :created_at, :modified_at, :tags) SENSITIVE = [] include Aws::Structure end |
#monitor_arn ⇒ String
The Amazon Resource Name (ARN) of the monitor.
331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331 class GetMonitorOutput < Struct.new( :monitor_arn, :monitor_name, :monitor_status, :local_resources, :remote_resources, :created_at, :modified_at, :tags) SENSITIVE = [] include Aws::Structure end |
#monitor_name ⇒ String
The name of the monitor.
331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331 class GetMonitorOutput < Struct.new( :monitor_arn, :monitor_name, :monitor_status, :local_resources, :remote_resources, :created_at, :modified_at, :tags) SENSITIVE = [] include Aws::Structure end |
#monitor_status ⇒ String
The status of a monitor. The status can be one of the following
-
PENDING: The monitor is in the process of being created. -
ACTIVE: The monitor is active. -
INACTIVE: The monitor is inactive. -
ERROR: Monitor creation failed due to an error. -
DELETING: The monitor is in the process of being deleted.
331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331 class GetMonitorOutput < Struct.new( :monitor_arn, :monitor_name, :monitor_status, :local_resources, :remote_resources, :created_at, :modified_at, :tags) SENSITIVE = [] include Aws::Structure end |
#remote_resources ⇒ Array<Types::MonitorRemoteResource>
The remote resources to monitor. A remote resource is the other endpoint specified for the network flow of a workload, with a local resource. For example, Amazon Dynamo DB can be a remote resource.
331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331 class GetMonitorOutput < Struct.new( :monitor_arn, :monitor_name, :monitor_status, :local_resources, :remote_resources, :created_at, :modified_at, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags for a monitor.
331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 331 class GetMonitorOutput < Struct.new( :monitor_arn, :monitor_name, :monitor_status, :local_resources, :remote_resources, :created_at, :modified_at, :tags) SENSITIVE = [] include Aws::Structure end |