Class: Aws::NetworkFlowMonitor::Types::GetQueryStatusWorkloadInsightsTopContributorsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFlowMonitor::Types::GetQueryStatusWorkloadInsightsTopContributorsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkflowmonitor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
When you run a query, use this call to check the status of the query to make sure that the query has
SUCCEEDEDbefore you review the results.
Instance Attribute Details
#status ⇒ String
When you run a query, use this call to check the status of the query to make sure that the query has SUCCEEDED before you review the results.
-
QUEUED: The query is scheduled to run. -
RUNNING: The query is in progress but not complete. -
SUCCEEDED: The query completed sucessfully. -
FAILED: The query failed due to an error. -
CANCELED: The query was canceled.
633 634 635 636 637 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 633 class GetQueryStatusWorkloadInsightsTopContributorsOutput < Struct.new( :status) SENSITIVE = [] include Aws::Structure end |