Class: Aws::NetworkFlowMonitor::Types::StartQueryMonitorTopContributorsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFlowMonitor::Types::StartQueryMonitorTopContributorsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkflowmonitor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_category ⇒ String
The category that you want to query top contributors for, for a specific monitor.
-
#end_time ⇒ Time
The timestamp that is the date and time end of the period that you want to retrieve results for with your query.
-
#limit ⇒ Integer
The maximum number of top contributors to return.
-
#metric_name ⇒ String
The metric that you want to query top contributors for.
-
#monitor_name ⇒ String
The name of the monitor.
-
#start_time ⇒ Time
The timestamp that is the date and time that is the beginning of the period that you want to retrieve results for with your query.
Instance Attribute Details
#destination_category ⇒ String
The category that you want to query top contributors for, for a specific monitor. Destination categories can be one of the following:
-
INTRA_AZ: Top contributor network flows within a single Availability Zone -
INTER_AZ: Top contributor network flows between Availability Zones -
INTER_REGION: Top contributor network flows between Regions (to the edge of another Region) -
INTER_VPC: Top contributor network flows between VPCs -
AMAZON_S3: Top contributor network flows to or from Amazon S3 -
AMAZON_DYNAMODB: Top contributor network flows to or from Amazon Dynamo DB -
UNCLASSIFIED: Top contributor network flows that do not have a bucket classification
1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1255 class StartQueryMonitorTopContributorsInput < Struct.new( :monitor_name, :start_time, :end_time, :metric_name, :destination_category, :limit) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The timestamp that is the date and time end of the period that you want to retrieve results for with your query.
1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1255 class StartQueryMonitorTopContributorsInput < Struct.new( :monitor_name, :start_time, :end_time, :metric_name, :destination_category, :limit) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of top contributors to return.
1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1255 class StartQueryMonitorTopContributorsInput < Struct.new( :monitor_name, :start_time, :end_time, :metric_name, :destination_category, :limit) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The metric that you want to query top contributors for. That is, you can specify a metric with this call and return the top contributor network flows, for that type of metric, for a monitor and (optionally) within a specific category, such as network flows between Availability Zones.
1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1255 class StartQueryMonitorTopContributorsInput < Struct.new( :monitor_name, :start_time, :end_time, :metric_name, :destination_category, :limit) SENSITIVE = [] include Aws::Structure end |
#monitor_name ⇒ String
The name of the monitor.
1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1255 class StartQueryMonitorTopContributorsInput < Struct.new( :monitor_name, :start_time, :end_time, :metric_name, :destination_category, :limit) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The timestamp that is the date and time that is the beginning of the period that you want to retrieve results for with your query.
1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1255 class StartQueryMonitorTopContributorsInput < Struct.new( :monitor_name, :start_time, :end_time, :metric_name, :destination_category, :limit) SENSITIVE = [] include Aws::Structure end |