Class: Aws::NetworkFlowMonitor::Types::StopQueryWorkloadInsightsTopContributorsDataInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFlowMonitor::Types::StopQueryWorkloadInsightsTopContributorsDataInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkflowmonitor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#query_id ⇒ String
The identifier for the query.
-
#scope_id ⇒ String
The identifier for the scope that includes the resources you want to get data results for.
Instance Attribute Details
#query_id ⇒ String
The identifier for the query. A query ID is an internally-generated identifier for a specific query returned from an API call to create a query.
1467 1468 1469 1470 1471 1472 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1467 class StopQueryWorkloadInsightsTopContributorsDataInput < Struct.new( :scope_id, :query_id) SENSITIVE = [] include Aws::Structure end |
#scope_id ⇒ String
The identifier for the scope that includes the resources you want to get data results for. A scope ID is an internally-generated identifier that includes all the resources for a specific root account.
1467 1468 1469 1470 1471 1472 |
# File 'lib/aws-sdk-networkflowmonitor/types.rb', line 1467 class StopQueryWorkloadInsightsTopContributorsDataInput < Struct.new( :scope_id, :query_id) SENSITIVE = [] include Aws::Structure end |